summaryrefslogtreecommitdiff
path: root/deps/v8/test/message/testcfg.py
diff options
context:
space:
mode:
Diffstat (limited to 'deps/v8/test/message/testcfg.py')
-rw-r--r--deps/v8/test/message/testcfg.py13
1 files changed, 7 insertions, 6 deletions
diff --git a/deps/v8/test/message/testcfg.py b/deps/v8/test/message/testcfg.py
index af467e699..9cb58264e 100644
--- a/deps/v8/test/message/testcfg.py
+++ b/deps/v8/test/message/testcfg.py
@@ -41,9 +41,10 @@ class MessageTestCase(test.TestCase):
self.config = config
def IgnoreLine(self, str):
"""Ignore empty lines and valgrind output."""
if not str: return True
- else: return str.startswith('==') or str.startswith('**')
+ return (str.startswith('==') or str.startswith('**') or
+ str.startswith('ANDROID'))
def IsFailureOutput(self, output):
f = file(self.expected)
@@ -62,7 +63,7 @@ class MessageTestCase(test.TestCase):
pattern = '^%s$' % pattern
patterns.append(pattern)
# Compare actual output with the expected
- raw_lines = output.stdout.split('\n')
+ raw_lines = output.stdout.splitlines()
outlines = [ s for s in raw_lines if not self.IgnoreLine(s) ]
if len(outlines) != len(patterns):
return True
@@ -80,9 +81,9 @@ class MessageTestCase(test.TestCase):
def GetCommand(self):
result = self.config.context.GetVmCommand(self, self.mode)
source = open(self.file).read()
- flags_match = FLAGS_PATTERN.search(source)
- if flags_match:
- result += flags_match.group(1).strip().split()
+ flags_match = re.findall(FLAGS_PATTERN, source)
+ for match in flags_match:
+ result += match.strip().split()
result.append(self.file)
return result
@@ -41,9 +41,10 @@ class MessageTestCase(test.TestCase):
self.config = config
def IgnoreLine(self, str):
- """Ignore empty lines and valgrind output."""
+ """Ignore empty lines, valgrind output and Android output."""
if not str: return True